/* context.c generated by valac 0.34.0.65-f52b, the Vala compiler
 * generated from context.vala, do not modify */

/* -*- Mode: vala; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * Copyright © 2014 Nikhar Agrawal
 * Copyright © 2015 Michael Catanzaro <mcatanzaro@gnome.org>
 *
 * This file is part of libgnome-games-support.
 *
 * libgnome-games-support is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * libgnome-games-support is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libgnome-games-support.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gstdio.h>
#include <errno.h>
#include <stdio.h>
#include <glib/gi18n-lib.h>


#define GAMES_SCORES_TYPE_STYLE (games_scores_style_get_type ())

#define GAMES_SCORES_TYPE_CONTEXT (games_scores_context_get_type ())
#define GAMES_SCORES_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_SCORES_TYPE_CONTEXT, GamesScoresContext))
#define GAMES_SCORES_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_SCORES_TYPE_CONTEXT, GamesScoresContextClass))
#define GAMES_SCORES_IS_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_SCORES_TYPE_CONTEXT))
#define GAMES_SCORES_IS_CONTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_SCORES_TYPE_CONTEXT))
#define GAMES_SCORES_CONTEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_SCORES_TYPE_CONTEXT, GamesScoresContextClass))

typedef struct _GamesScoresContext GamesScoresContext;
typedef struct _GamesScoresContextClass GamesScoresContextClass;
typedef struct _GamesScoresContextPrivate GamesScoresContextPrivate;

#define GAMES_SCORES_TYPE_CATEGORY (games_scores_category_get_type ())
#define GAMES_SCORES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_SCORES_TYPE_CATEGORY, GamesScoresCategory))
#define GAMES_SCORES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_SCORES_TYPE_CATEGORY, GamesScoresCategoryClass))
#define GAMES_SCORES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_SCORES_TYPE_CATEGORY))
#define GAMES_SCORES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_SCORES_TYPE_CATEGORY))
#define GAMES_SCORES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_SCORES_TYPE_CATEGORY, GamesScoresCategoryClass))

typedef struct _GamesScoresCategory GamesScoresCategory;
typedef struct _GamesScoresCategoryClass GamesScoresCategoryClass;

#define GAMES_SCORES_TYPE_SCORE (games_scores_score_get_type ())
#define GAMES_SCORES_SCORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_SCORES_TYPE_SCORE, GamesScoresScore))
#define GAMES_SCORES_SCORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_SCORES_TYPE_SCORE, GamesScoresScoreClass))
#define GAMES_SCORES_IS_SCORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_SCORES_TYPE_SCORE))
#define GAMES_SCORES_IS_SCORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_SCORES_TYPE_SCORE))
#define GAMES_SCORES_SCORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_SCORES_TYPE_SCORE, GamesScoresScoreClass))

typedef struct _GamesScoresScore GamesScoresScore;
typedef struct _GamesScoresScoreClass GamesScoresScoreClass;

#define GAMES_SCORES_TYPE_IMPORTER (games_scores_importer_get_type ())
#define GAMES_SCORES_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_SCORES_TYPE_IMPORTER, GamesScoresImporter))
#define GAMES_SCORES_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_SCORES_TYPE_IMPORTER, GamesScoresImporterClass))
#define GAMES_SCORES_IS_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_SCORES_TYPE_IMPORTER))
#define GAMES_SCORES_IS_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_SCORES_TYPE_IMPORTER))
#define GAMES_SCORES_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_SCORES_TYPE_IMPORTER, GamesScoresImporterClass))

typedef struct _GamesScoresImporter GamesScoresImporter;
typedef struct _GamesScoresImporterClass GamesScoresImporterClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block1Data Block1Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _GamesScoresContextSaveScoreToFileData GamesScoresContextSaveScoreToFileData;
typedef struct _GamesScoresContextAddScoreInternalData GamesScoresContextAddScoreInternalData;
typedef struct _GamesScoresContextAddScoreData GamesScoresContextAddScoreData;
typedef struct _Block3Data Block3Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
#define _g_main_context_unref0(var) ((var == NULL) ? NULL : (var = (g_main_context_unref (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _fclose0(var) ((var == NULL) ? NULL : (var = (fclose (var), NULL)))

#define GAMES_SCORES_TYPE_DIALOG (games_scores_dialog_get_type ())
#define GAMES_SCORES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAMES_SCORES_TYPE_DIALOG, GamesScoresDialog))
#define GAMES_SCORES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GAMES_SCORES_TYPE_DIALOG, GamesScoresDialogClass))
#define GAMES_SCORES_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAMES_SCORES_TYPE_DIALOG))
#define GAMES_SCORES_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GAMES_SCORES_TYPE_DIALOG))
#define GAMES_SCORES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GAMES_SCORES_TYPE_DIALOG, GamesScoresDialogClass))

typedef struct _GamesScoresDialog GamesScoresDialog;
typedef struct _GamesScoresDialogClass GamesScoresDialogClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	GAMES_SCORES_STYLE_POINTS_GREATER_IS_BETTER,
	GAMES_SCORES_STYLE_POINTS_LESS_IS_BETTER,
	GAMES_SCORES_STYLE_TIME_GREATER_IS_BETTER,
	GAMES_SCORES_STYLE_TIME_LESS_IS_BETTER
} GamesScoresStyle;

struct _GamesScoresContext {
	GObject parent_instance;
	GamesScoresContextPrivate * priv;
};

struct _GamesScoresContextClass {
	GObjectClass parent_class;
};

typedef GamesScoresCategory* (*GamesScoresContextCategoryRequestFunc) (const gchar* category_key, void* user_data);
struct _GamesScoresContextPrivate {
	GamesScoresCategory* current_category;
	GamesScoresStyle style;
	gchar* category_type;
	GtkWindow* game_window;
	gchar* app_name;
	GeeHashMap* scores_per_category;
	gchar* user_score_dir;
	GCompareDataFunc scorecmp;
	gpointer scorecmp_target;
	GDestroyNotify scorecmp_target_destroy_notify;
	GamesScoresContextCategoryRequestFunc category_request;
	gpointer category_request_target;
	GDestroyNotify category_request_target_destroy_notify;
	GamesScoresImporter* importer;
};

struct _Block1Data {
	int _ref_count_;
	GamesScoresContext* self;
	GamesScoresContextCategoryRequestFunc category_request;
	gpointer category_request_target;
};

struct _Block2Data {
	int _ref_count_;
	GamesScoresContext* self;
	GeePriorityQueue* scores_of_this_category;
};

struct _GamesScoresContextSaveScoreToFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GamesScoresContext* self;
	GamesScoresScore* score;
	GamesScoresCategory* category;
	GCancellable* cancellable;
	const gchar* _tmp0_;
	gint _tmp1_;
	const gchar* _tmp2_;
	gint _tmp3_;
	const gchar* _tmp4_;
	GError* _tmp5_;
	GFile* file;
	const gchar* _tmp6_;
	GamesScoresCategory* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	GFile* _tmp12_;
	GFile* _tmp13_;
	GFileOutputStream* stream;
	GFile* _tmp14_;
	GFileOutputStream* _tmp15_;
	gchar* line;
	GamesScoresScore* _tmp16_;
	glong _tmp17_;
	glong _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	GamesScoresScore* _tmp21_;
	gint64 _tmp22_;
	gint64 _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	GamesScoresScore* _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	GFileOutputStream* _tmp32_;
	const gchar* _tmp33_;
	guint8* _tmp34_;
	gint _tmp34__length1;
	guint8* _tmp35_;
	gint _tmp35__length1;
	GCancellable* _tmp36_;
	GError * _inner_error_;
};

struct _GamesScoresContextAddScoreInternalData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GamesScoresContext* self;
	GamesScoresScore* score;
	GamesScoresCategory* category;
	gboolean allow_dialog;
	GCancellable* cancellable;
	gboolean result;
	gboolean high_score_added;
	GamesScoresScore* _tmp0_;
	glong _tmp1_;
	glong _tmp2_;
	GamesScoresCategory* _tmp3_;
	gboolean _tmp4_;
	GeeHashMap* _tmp5_;
	GamesScoresCategory* _tmp6_;
	gboolean _tmp7_;
	GeeHashMap* _tmp8_;
	GamesScoresCategory* _tmp9_;
	GCompareDataFunc _tmp10_;
	void* _tmp10__target;
	GDestroyNotify _tmp10__target_destroy_notify;
	GeePriorityQueue* _tmp11_;
	GeePriorityQueue* _tmp12_;
	GeeHashMap* _tmp13_;
	GamesScoresCategory* _tmp14_;
	gpointer _tmp15_;
	GeePriorityQueue* _tmp16_;
	GamesScoresScore* _tmp17_;
	gboolean _tmp18_;
	gboolean _tmp19_;
	GamesScoresCategory* _tmp20_;
	GamesScoresCategory* _tmp21_;
	gboolean _tmp22_;
	gboolean _tmp23_;
	gboolean _tmp24_;
	GamesScoresScore* _tmp25_;
	GamesScoresScore* _tmp26_;
	GamesScoresCategory* _tmp27_;
	GCancellable* _tmp28_;
	GError * _inner_error_;
};

struct _GamesScoresContextAddScoreData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GamesScoresContext* self;
	glong score;
	GamesScoresCategory* category;
	GCancellable* cancellable;
	gboolean result;
	gboolean _tmp0_;
	glong _tmp1_;
	GamesScoresScore* _tmp2_;
	GamesScoresScore* _tmp3_;
	GamesScoresCategory* _tmp4_;
	GtkWindow* _tmp5_;
	GCancellable* _tmp6_;
	gboolean _tmp7_;
	gboolean _tmp8_;
	GError * _inner_error_;
};

struct _Block3Data {
	int _ref_count_;
	GamesScoresContext* self;
	GMainLoop* main_loop;
	gboolean ret;
	GError* _error_;
};


static gpointer games_scores_context_parent_class = NULL;
static GeeHashDataFunc games_scores_context_category_hash;
static gpointer games_scores_context_category_hash_target;
static GDestroyNotify games_scores_context_category_hash_target_destroy_notify;
static GeeEqualDataFunc games_scores_context_category_equal;
static gpointer games_scores_context_category_equal_target;
static GDestroyNotify games_scores_context_category_equal_target_destroy_notify;
static GeeHashDataFunc games_scores_context_category_hash = NULL;
static gpointer games_scores_context_category_hash_target = NULL;
static GDestroyNotify games_scores_context_category_hash_target_destroy_notify = NULL;
static GeeEqualDataFunc games_scores_context_category_equal = NULL;
static gpointer games_scores_context_category_equal_target = NULL;
static GDestroyNotify games_scores_context_category_equal_target_destroy_notify = NULL;

GType games_scores_style_get_type (void) G_GNUC_CONST;
GType games_scores_context_get_type (void) G_GNUC_CONST;
GType games_scores_category_get_type (void) G_GNUC_CONST;
GType games_scores_score_get_type (void) G_GNUC_CONST;
GType games_scores_importer_get_type (void) G_GNUC_CONST;
#define GAMES_SCORES_CONTEXT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GAMES_SCORES_TYPE_CONTEXT, GamesScoresContextPrivate))
enum  {
	GAMES_SCORES_CONTEXT_DUMMY_PROPERTY
};
static guint _games_scores_context_category_hash_lambda4_ (GamesScoresCategory* a);
const gchar* games_scores_category_get_key (GamesScoresCategory* self);
static guint __games_scores_context_category_hash_lambda4__gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _games_scores_context_category_equal_lambda5_ (GamesScoresCategory* a, GamesScoresCategory* b);
static gboolean __games_scores_context_category_equal_lambda5__gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
GamesScoresContext* games_scores_context_new (const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style);
GamesScoresContext* games_scores_context_construct (GType object_type, const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style);
GamesScoresContext* games_scores_context_new_with_importer (const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style, GamesScoresImporter* importer);
GamesScoresContext* games_scores_context_construct_with_importer (GType object_type, const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style, GamesScoresImporter* importer);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static GamesScoresCategory* __lambda6_ (Block1Data* _data1_, const gchar* key);
static GamesScoresCategory* ___lambda6__games_scores_context_category_request_func (const gchar* category_key, gpointer self);
static gint ___lambda7_ (GamesScoresContext* self, GamesScoresScore* a, GamesScoresScore* b);
glong games_scores_score_get_score (GamesScoresScore* self);
static gint ____lambda7__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gint ___lambda8_ (GamesScoresContext* self, GamesScoresScore* a, GamesScoresScore* b);
static gint ____lambda8__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self);
void games_scores_importer_run (GamesScoresImporter* self, GamesScoresContext* context, const gchar* new_scores_dir);
static void games_scores_context_load_scores_from_files (GamesScoresContext* self, GError** error);
GList* games_scores_context_get_categories (GamesScoresContext* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void games_scores_context_update_score_name (GamesScoresContext* self, GamesScoresScore* old_score, GamesScoresCategory* category, const gchar* new_name);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
gboolean games_scores_score_equals (GamesScoresScore* a, GamesScoresScore* b);
void games_scores_score_set_user (GamesScoresScore* self, const gchar* value);
static void __lambda9_ (Block2Data* _data2_, GamesScoresScore* x);
static void ___lambda9__gfunc (gconstpointer data, gpointer self);
GeeList* games_scores_context_get_high_scores (GamesScoresContext* self, GamesScoresCategory* category, gint n);
static gboolean games_scores_context_is_high_score (GamesScoresContext* self, glong score_value, GamesScoresCategory* category);
static void games_scores_context_save_score_to_file_data_free (gpointer _data);
static void games_scores_context_save_score_to_file (GamesScoresContext* self, GamesScoresScore* score, GamesScoresCategory* category, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void games_scores_context_save_score_to_file_finish (GamesScoresContext* self, GAsyncResult* _res_, GError** error);
static gboolean games_scores_context_save_score_to_file_co (GamesScoresContextSaveScoreToFileData* _data_);
gint64 games_scores_score_get_time (GamesScoresScore* self);
const gchar* games_scores_score_get_user (GamesScoresScore* self);
static void games_scores_context_save_score_to_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void games_scores_context_add_score_internal_data_free (gpointer _data);
void games_scores_context_add_score_internal (GamesScoresContext* self, GamesScoresScore* score, GamesScoresCategory* category, gboolean allow_dialog, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean games_scores_context_add_score_internal_finish (GamesScoresContext* self, GAsyncResult* _res_, GError** error);
static gboolean games_scores_context_add_score_internal_co (GamesScoresContextAddScoreInternalData* _data_);
void games_scores_context_run_dialog_internal (GamesScoresContext* self, GamesScoresScore* new_high_score);
static void games_scores_context_add_score_internal_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void games_scores_context_add_score_data_free (gpointer _data);
void games_scores_context_add_score (GamesScoresContext* self, glong score, GamesScoresCategory* category, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean games_scores_context_add_score_finish (GamesScoresContext* self, GAsyncResult* _res_, GError** error);
static gboolean games_scores_context_add_score_co (GamesScoresContextAddScoreData* _data_);
GamesScoresScore* games_scores_score_new (glong score, gint64 time, const gchar* user);
GamesScoresScore* games_scores_score_construct (GType object_type, glong score, gint64 time, const gchar* user);
static void games_scores_context_add_score_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gboolean games_scores_context_add_score_sync (GamesScoresContext* self, GamesScoresScore* score, GamesScoresCategory* category, GError** error);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda12_ (Block3Data* _data3_, GObject* object, GAsyncResult* _result_);
static void ___lambda12__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void games_scores_context_load_scores_from_file (GamesScoresContext* self, GFileInfo* file_info, GError** error);
GType games_scores_dialog_get_type (void) G_GNUC_CONST;
GamesScoresDialog* games_scores_dialog_new (GamesScoresContext* context, const gchar* category_type, GamesScoresStyle style, GamesScoresScore* new_high_score, GamesScoresCategory* current_cat, GtkWindow* window, const gchar* app_name);
GamesScoresDialog* games_scores_dialog_construct (GType object_type, GamesScoresContext* context, const gchar* category_type, GamesScoresStyle style, GamesScoresScore* new_high_score, GamesScoresCategory* current_cat, GtkWindow* window, const gchar* app_name);
void games_scores_context_run_dialog (GamesScoresContext* self);
gboolean games_scores_context_has_scores (GamesScoresContext* self);
static void games_scores_context_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


GType games_scores_style_get_type (void) {
	static volatile gsize games_scores_style_type_id__volatile = 0;
	if (g_once_init_enter (&games_scores_style_type_id__volatile)) {
		static const GEnumValue values[] = {{GAMES_SCORES_STYLE_POINTS_GREATER_IS_BETTER, "GAMES_SCORES_STYLE_POINTS_GREATER_IS_BETTER", "points-greater-is-better"}, {GAMES_SCORES_STYLE_POINTS_LESS_IS_BETTER, "GAMES_SCORES_STYLE_POINTS_LESS_IS_BETTER", "points-less-is-better"}, {GAMES_SCORES_STYLE_TIME_GREATER_IS_BETTER, "GAMES_SCORES_STYLE_TIME_GREATER_IS_BETTER", "time-greater-is-better"}, {GAMES_SCORES_STYLE_TIME_LESS_IS_BETTER, "GAMES_SCORES_STYLE_TIME_LESS_IS_BETTER", "time-less-is-better"}, {0, NULL, NULL}};
		GType games_scores_style_type_id;
		games_scores_style_type_id = g_enum_register_static ("GamesScoresStyle", values);
		g_once_init_leave (&games_scores_style_type_id__volatile, games_scores_style_type_id);
	}
	return games_scores_style_type_id__volatile;
}


static guint _games_scores_context_category_hash_lambda4_ (GamesScoresCategory* a) {
	guint result = 0U;
	GHashFunc _tmp0_ = NULL;
	GamesScoresCategory* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = g_str_hash;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = a;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = games_scores_category_get_key (_tmp1_);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = _tmp2_;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = _tmp0_ (_tmp3_);
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _tmp4_;
#line 50 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 413 "context.c"
}


static guint __games_scores_context_category_hash_lambda4__gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = _games_scores_context_category_hash_lambda4_ ((GamesScoresCategory*) v);
#line 49 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 422 "context.c"
}


static gboolean _games_scores_context_category_equal_lambda5_ (GamesScoresCategory* a, GamesScoresCategory* b) {
	gboolean result = FALSE;
	GEqualFunc _tmp0_ = NULL;
	GamesScoresCategory* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GamesScoresCategory* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = g_str_equal;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = a;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = games_scores_category_get_key (_tmp1_);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = _tmp2_;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = b;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = games_scores_category_get_key (_tmp4_);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = _tmp5_;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = _tmp0_ (_tmp3_, _tmp6_);
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _tmp7_;
#line 54 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 456 "context.c"
}


static gboolean __games_scores_context_category_equal_lambda5__gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = _games_scores_context_category_equal_lambda5_ ((GamesScoresCategory*) a, (GamesScoresCategory*) b);
#line 53 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 465 "context.c"
}


GamesScoresContext* games_scores_context_construct (GType object_type, const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style) {
	GamesScoresContext * self = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GtkWindow* _tmp2_ = NULL;
	GamesScoresContextCategoryRequestFunc _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	GamesScoresStyle _tmp4_ = 0;
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (app_name != NULL, NULL);
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (category_type != NULL, NULL);
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = app_name;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = category_type;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = game_window;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = category_request;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3__target = category_request_target;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = style;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self = (GamesScoresContext*) games_scores_context_construct_with_importer (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp3_, _tmp3__target, _tmp4_, NULL);
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return self;
#line 497 "context.c"
}


GamesScoresContext* games_scores_context_new (const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style) {
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return games_scores_context_construct (GAMES_SCORES_TYPE_CONTEXT, app_name, category_type, game_window, category_request, category_request_target, style);
#line 504 "context.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return _data1_;
#line 513 "context.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 522 "context.c"
		GamesScoresContext* self;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self = _data1_->self;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (self);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_slice_free (Block1Data, _data1_);
#line 530 "context.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return self ? g_object_ref (self) : NULL;
#line 538 "context.c"
}


static GamesScoresCategory* __lambda6_ (Block1Data* _data1_, const gchar* key) {
	GamesScoresContext* self;
	GamesScoresCategory* result = NULL;
	GamesScoresContextCategoryRequestFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	const gchar* _tmp1_ = NULL;
	GamesScoresCategory* _tmp2_ = NULL;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self = _data1_->self;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (key != NULL, NULL);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = _data1_->category_request;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0__target = _data1_->category_request_target;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = key;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = _tmp0_ (_tmp1_, _tmp0__target);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _tmp2_;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 565 "context.c"
}


static GamesScoresCategory* ___lambda6__games_scores_context_category_request_func (const gchar* category_key, gpointer self) {
	GamesScoresCategory* result;
	result = __lambda6_ (self, category_key);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 574 "context.c"
}


static gint ___lambda7_ (GamesScoresContext* self, GamesScoresScore* a, GamesScoresScore* b) {
	gint result = 0;
	GamesScoresScore* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	glong _tmp2_ = 0L;
	GamesScoresScore* _tmp3_ = NULL;
	glong _tmp4_ = 0L;
	glong _tmp5_ = 0L;
	GamesScoresScore* _tmp6_ = NULL;
	glong _tmp7_ = 0L;
	glong _tmp8_ = 0L;
	GamesScoresScore* _tmp9_ = NULL;
	glong _tmp10_ = 0L;
	glong _tmp11_ = 0L;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = b;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = games_scores_score_get_score (_tmp0_);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = _tmp1_;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = a;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = games_scores_score_get_score (_tmp3_);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = _tmp4_;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = a;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = games_scores_score_get_score (_tmp6_);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = _tmp7_;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp9_ = b;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10_ = games_scores_score_get_score (_tmp9_);
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp11_ = _tmp10_;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = ((gint) (_tmp2_ > _tmp5_)) - ((gint) (_tmp8_ > _tmp11_));
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 620 "context.c"
}


static gint ____lambda7__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = ___lambda7_ ((GamesScoresContext*) self, (GamesScoresScore*) a, (GamesScoresScore*) b);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 629 "context.c"
}


static gint ___lambda8_ (GamesScoresContext* self, GamesScoresScore* a, GamesScoresScore* b) {
	gint result = 0;
	GamesScoresScore* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	glong _tmp2_ = 0L;
	GamesScoresScore* _tmp3_ = NULL;
	glong _tmp4_ = 0L;
	glong _tmp5_ = 0L;
	GamesScoresScore* _tmp6_ = NULL;
	glong _tmp7_ = 0L;
	glong _tmp8_ = 0L;
	GamesScoresScore* _tmp9_ = NULL;
	glong _tmp10_ = 0L;
	glong _tmp11_ = 0L;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = b;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = games_scores_score_get_score (_tmp0_);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = _tmp1_;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = a;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = games_scores_score_get_score (_tmp3_);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = _tmp4_;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = a;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = games_scores_score_get_score (_tmp6_);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = _tmp7_;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp9_ = b;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10_ = games_scores_score_get_score (_tmp9_);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp11_ = _tmp10_;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = ((gint) (_tmp2_ < _tmp5_)) - ((gint) (_tmp8_ < _tmp11_));
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 675 "context.c"
}


static gint ____lambda8__gcompare_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gint result;
	result = ___lambda8_ ((GamesScoresContext*) self, (GamesScoresScore*) a, (GamesScoresScore*) b);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 684 "context.c"
}


GamesScoresContext* games_scores_context_construct_with_importer (GType object_type, const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style, GamesScoresImporter* importer) {
	GamesScoresContext * self = NULL;
	Block1Data* _data1_;
	GamesScoresContextCategoryRequestFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GtkWindow* _tmp5_ = NULL;
	GtkWindow* _tmp6_ = NULL;
	GamesScoresStyle _tmp7_ = 0;
	GamesScoresImporter* _tmp8_ = NULL;
	GamesScoresImporter* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GamesScoresStyle _tmp11_ = 0;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	GamesScoresImporter* _tmp16_ = NULL;
	GError * _inner_error_ = NULL;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (app_name != NULL, NULL);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (category_type != NULL, NULL);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data1_->_ref_count_ = 1;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = category_request;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0__target = category_request_target;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data1_->category_request = _tmp0_;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data1_->category_request_target = _tmp0__target;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self = (GamesScoresContext*) g_object_new (object_type, NULL);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data1_->self = g_object_ref (self);
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = app_name;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (self->priv->app_name);
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->app_name = _tmp2_;
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = category_type;
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (self->priv->category_type);
#line 91 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_type = _tmp4_;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = game_window;
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (self->priv->game_window);
#line 92 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->game_window = _tmp6_;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	(self->priv->category_request_target_destroy_notify == NULL) ? NULL : (self->priv->category_request_target_destroy_notify (self->priv->category_request_target), NULL);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request = NULL;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request_target = NULL;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request_target_destroy_notify = NULL;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request = ___lambda6__games_scores_context_category_request_func;
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request_target = block1_data_ref (_data1_);
#line 93 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request_target_destroy_notify = block1_data_unref;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = style;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->style = _tmp7_;
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = importer;
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (self->priv->importer);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->importer = _tmp9_;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp11_ = style;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp11_ == GAMES_SCORES_STYLE_POINTS_GREATER_IS_BETTER) {
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp10_ = TRUE;
#line 785 "context.c"
	} else {
		GamesScoresStyle _tmp12_ = 0;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp12_ = style;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp10_ = _tmp12_ == GAMES_SCORES_STYLE_TIME_GREATER_IS_BETTER;
#line 792 "context.c"
	}
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp10_) {
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		(self->priv->scorecmp_target_destroy_notify == NULL) ? NULL : (self->priv->scorecmp_target_destroy_notify (self->priv->scorecmp_target), NULL);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp = NULL;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target = NULL;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target_destroy_notify = NULL;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp = ____lambda7__gcompare_data_func;
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target = g_object_ref (self);
#line 99 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target_destroy_notify = g_object_unref;
#line 810 "context.c"
	} else {
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		(self->priv->scorecmp_target_destroy_notify == NULL) ? NULL : (self->priv->scorecmp_target_destroy_notify (self->priv->scorecmp_target), NULL);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp = NULL;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target = NULL;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target_destroy_notify = NULL;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp = ____lambda8__gcompare_data_func;
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target = g_object_ref (self);
#line 105 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self->priv->scorecmp_target_destroy_notify = g_object_unref;
#line 826 "context.c"
	}
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp13_ = g_get_user_data_dir ();
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp14_ = app_name;
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp15_ = g_build_filename (_tmp13_, _tmp14_, "scores", NULL, NULL);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (self->priv->user_score_dir);
#line 110 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->user_score_dir = _tmp15_;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp16_ = importer;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp16_ != NULL) {
#line 842 "context.c"
		GamesScoresImporter* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp17_ = importer;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp18_ = self->priv->user_score_dir;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		games_scores_importer_run (_tmp17_, self, _tmp18_);
#line 851 "context.c"
	}
	{
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		games_scores_context_load_scores_from_files (self, &_inner_error_);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 858 "context.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		e = _inner_error_;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_inner_error_ = NULL;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp19_ = e;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp20_ = _tmp19_->message;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_warning ("context.vala:121: Failed to load scores: %s", _tmp20_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_error_free0 (e);
#line 880 "context.c"
	}
	__finally0:
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		block1_data_unref (_data1_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data1_ = NULL;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_clear_error (&_inner_error_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return NULL;
#line 895 "context.c"
	}
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	block1_data_unref (_data1_);
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data1_ = NULL;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return self;
#line 903 "context.c"
}


GamesScoresContext* games_scores_context_new_with_importer (const gchar* app_name, const gchar* category_type, GtkWindow* game_window, GamesScoresContextCategoryRequestFunc category_request, void* category_request_target, GamesScoresStyle style, GamesScoresImporter* importer) {
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return games_scores_context_construct_with_importer (GAMES_SCORES_TYPE_CONTEXT, app_name, category_type, game_window, category_request, category_request_target, style, importer);
#line 910 "context.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 917 "context.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_list_free (self);
#line 926 "context.c"
}


GList* games_scores_context_get_categories (GamesScoresContext* self) {
	GList* result = NULL;
	GList* categories = NULL;
	GeeMapIterator* iterator = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GeeMapIterator* _tmp1_ = NULL;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 127 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	categories = NULL;
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = self->priv->scores_per_category;
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = gee_abstract_map_map_iterator ((GeeAbstractMap*) _tmp0_);
#line 128 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	iterator = _tmp1_;
#line 130 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	while (TRUE) {
#line 948 "context.c"
		GeeMapIterator* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		GeeMapIterator* _tmp4_ = NULL;
		gpointer _tmp5_ = NULL;
#line 130 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp2_ = iterator;
#line 130 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp3_ = gee_map_iterator_next (_tmp2_);
#line 130 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (!_tmp3_) {
#line 130 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			break;
#line 961 "context.c"
		}
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp4_ = iterator;
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp5_ = gee_map_iterator_get_key (_tmp4_);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		categories = g_list_append (categories, (GamesScoresCategory*) _tmp5_);
#line 969 "context.c"
	}
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = categories;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (iterator);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 977 "context.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return _data2_;
#line 986 "context.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 995 "context.c"
		GamesScoresContext* self;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self = _data2_->self;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_data2_->scores_of_this_category);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (self);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_slice_free (Block2Data, _data2_);
#line 1005 "context.c"
	}
}


static void __lambda9_ (Block2Data* _data2_, GamesScoresScore* x) {
	GamesScoresContext* self;
	GeePriorityQueue* _tmp0_ = NULL;
	GamesScoresScore* _tmp1_ = NULL;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self = _data2_->self;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (x != NULL);
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = _data2_->scores_of_this_category;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = x;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp0_, _tmp1_);
#line 1024 "context.c"
}


static void ___lambda9__gfunc (gconstpointer data, gpointer self) {
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	__lambda9_ (self, (GamesScoresScore*) data);
#line 1031 "context.c"
}


void games_scores_context_update_score_name (GamesScoresContext* self, GamesScoresScore* old_score, GamesScoresCategory* category, const gchar* new_name) {
	Block2Data* _data2_;
	GList* list_scores = NULL;
	GeeHashMap* _tmp0_ = NULL;
	GamesScoresCategory* _tmp1_ = NULL;
	gpointer _tmp2_ = NULL;
	GamesScoresScore* score = NULL;
	GList* _tmp17_ = NULL;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (self != NULL);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (old_score != NULL);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (category != NULL);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (new_name != NULL);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data2_->_ref_count_ = 1;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data2_->self = g_object_ref (self);
#line 141 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	list_scores = NULL;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = self->priv->scores_per_category;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = category;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp0_, _tmp1_);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data2_->scores_of_this_category = (GeePriorityQueue*) _tmp2_;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	score = NULL;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	while (TRUE) {
#line 1071 "context.c"
		GeePriorityQueue* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		GeePriorityQueue* _tmp6_ = NULL;
		gpointer _tmp7_ = NULL;
		GamesScoresScore* _tmp8_ = NULL;
		GamesScoresScore* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp3_ = _data2_->scores_of_this_category;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp4_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp3_);
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp5_ = _tmp4_;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (!(_tmp5_ > 0)) {
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			break;
#line 1090 "context.c"
		}
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp6_ = _data2_->scores_of_this_category;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp7_ = gee_abstract_queue_poll ((GeeAbstractQueue*) _tmp6_);
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (score);
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		score = (GamesScoresScore*) _tmp7_;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp8_ = score;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp9_ = old_score;
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp10_ = games_scores_score_equals (_tmp8_, _tmp9_);
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_tmp10_) {
#line 1108 "context.c"
			GamesScoresScore* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			GamesScoresScore* _tmp13_ = NULL;
			GamesScoresScore* _tmp14_ = NULL;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp11_ = score;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp12_ = new_name;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			games_scores_score_set_user (_tmp11_, _tmp12_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp13_ = score;
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp14_ = _g_object_ref0 (_tmp13_);
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			list_scores = g_list_append (list_scores, _tmp14_);
#line 153 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			break;
#line 1127 "context.c"
		} else {
			GamesScoresScore* _tmp15_ = NULL;
			GamesScoresScore* _tmp16_ = NULL;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp15_ = score;
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp16_ = _g_object_ref0 (_tmp15_);
#line 156 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			list_scores = g_list_append (list_scores, _tmp16_);
#line 1137 "context.c"
		}
	}
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp17_ = list_scores;
#line 159 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_list_foreach (_tmp17_, ___lambda9__gfunc, _data2_);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (score);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	__g_list_free__g_object_unref0_0 (list_scores);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	block2_data_unref (_data2_);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data2_ = NULL;
#line 1152 "context.c"
}


GeeList* games_scores_context_get_high_scores (GamesScoresContext* self, GamesScoresCategory* category, gint n) {
	GeeList* result = NULL;
	GeeArrayList* _result_ = NULL;
	GeeArrayList* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GamesScoresCategory* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 163 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (category != NULL, NULL);
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = gee_array_list_new (GAMES_SCORES_TYPE_SCORE, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 165 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_result_ = _tmp0_;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = self->priv->scores_per_category;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = category;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp1_, _tmp2_);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (!_tmp3_) {
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		result = (GeeList*) _result_;
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return result;
#line 1183 "context.c"
	}
	{
		gint i = 0;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		i = 0;
#line 1189 "context.c"
		{
			gboolean _tmp4_ = FALSE;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp4_ = TRUE;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			while (TRUE) {
#line 1196 "context.c"
				gboolean _tmp6_ = FALSE;
				gint _tmp7_ = 0;
				gint _tmp8_ = 0;
				GeeArrayList* _tmp15_ = NULL;
				GeeHashMap* _tmp16_ = NULL;
				GamesScoresCategory* _tmp17_ = NULL;
				gpointer _tmp18_ = NULL;
				GeePriorityQueue* _tmp19_ = NULL;
				gpointer _tmp20_ = NULL;
				GamesScoresScore* _tmp21_ = NULL;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				if (!_tmp4_) {
#line 1209 "context.c"
					gint _tmp5_ = 0;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp5_ = i;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					i = _tmp5_ + 1;
#line 1215 "context.c"
				}
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp4_ = FALSE;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp7_ = i;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp8_ = n;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				if (_tmp7_ < _tmp8_) {
#line 1225 "context.c"
					GeeHashMap* _tmp9_ = NULL;
					GamesScoresCategory* _tmp10_ = NULL;
					gpointer _tmp11_ = NULL;
					GeePriorityQueue* _tmp12_ = NULL;
					gint _tmp13_ = 0;
					gint _tmp14_ = 0;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp9_ = self->priv->scores_per_category;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp10_ = category;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp11_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp9_, _tmp10_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp12_ = (GeePriorityQueue*) _tmp11_;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp13_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp12_);
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp14_ = _tmp13_;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp6_ = _tmp14_ > 0;
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_g_object_unref0 (_tmp12_);
#line 1248 "context.c"
				} else {
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					_tmp6_ = FALSE;
#line 1252 "context.c"
				}
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				if (!_tmp6_) {
#line 171 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
					break;
#line 1258 "context.c"
				}
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp15_ = _result_;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp16_ = self->priv->scores_per_category;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp17_ = category;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp18_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp16_, _tmp17_);
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp19_ = (GeePriorityQueue*) _tmp18_;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp20_ = gee_abstract_queue_poll ((GeeAbstractQueue*) _tmp19_);
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp21_ = (GamesScoresScore*) _tmp20_;
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp15_, _tmp21_);
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_g_object_unref0 (_tmp21_);
#line 172 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_g_object_unref0 (_tmp19_);
#line 1280 "context.c"
			}
		}
	}
	{
		GeeArrayList* _score_list = NULL;
		GeeArrayList* _tmp22_ = NULL;
		GeeArrayList* _tmp23_ = NULL;
		gint _score_size = 0;
		GeeArrayList* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		gint _score_index = 0;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp22_ = _result_;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp23_ = _g_object_ref0 (_tmp22_);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_score_list = _tmp23_;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp24_ = _score_list;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp25_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp24_);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp26_ = _tmp25_;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_score_size = _tmp26_;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_score_index = -1;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		while (TRUE) {
#line 1311 "context.c"
			gint _tmp27_ = 0;
			gint _tmp28_ = 0;
			gint _tmp29_ = 0;
			GamesScoresScore* score = NULL;
			GeeArrayList* _tmp30_ = NULL;
			gint _tmp31_ = 0;
			gpointer _tmp32_ = NULL;
			GeeHashMap* _tmp33_ = NULL;
			GamesScoresCategory* _tmp34_ = NULL;
			gpointer _tmp35_ = NULL;
			GeePriorityQueue* _tmp36_ = NULL;
			GamesScoresScore* _tmp37_ = NULL;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp27_ = _score_index;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_score_index = _tmp27_ + 1;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp28_ = _score_index;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp29_ = _score_size;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			if (!(_tmp28_ < _tmp29_)) {
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				break;
#line 1336 "context.c"
			}
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp30_ = _score_list;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp31_ = _score_index;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp32_ = gee_abstract_list_get ((GeeAbstractList*) _tmp30_, _tmp31_);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			score = (GamesScoresScore*) _tmp32_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp33_ = self->priv->scores_per_category;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp34_ = category;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp35_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp33_, _tmp34_);
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp36_ = (GeePriorityQueue*) _tmp35_;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp37_ = score;
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _tmp36_, _tmp37_);
#line 174 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (_tmp36_);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (score);
#line 1362 "context.c"
		}
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_score_list);
#line 1366 "context.c"
	}
#line 176 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = (GeeList*) _result_;
#line 176 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 1372 "context.c"
}


static gboolean games_scores_context_is_high_score (GamesScoresContext* self, glong score_value, GamesScoresCategory* category) {
	gboolean result = FALSE;
	GeeList* best_scores = NULL;
	GamesScoresCategory* _tmp0_ = NULL;
	GeeList* _tmp1_ = NULL;
	GeeList* _tmp2_ = NULL;
	GeeList* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	glong lowest = 0L;
	GeeList* _tmp6_ = NULL;
	gpointer _tmp7_ = NULL;
	GamesScoresScore* _tmp8_ = NULL;
	glong _tmp9_ = 0L;
	glong _tmp10_ = 0L;
	glong _tmp11_ = 0L;
	gboolean _tmp12_ = FALSE;
	GamesScoresStyle _tmp13_ = 0;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
#line 179 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 179 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (category != NULL, FALSE);
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = category;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = games_scores_context_get_high_scores (self, _tmp0_, 10);
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	best_scores = _tmp1_;
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = best_scores;
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp2_ == NULL) {
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		result = TRUE;
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (best_scores);
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return result;
#line 1416 "context.c"
	}
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = best_scores;
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = _tmp4_;
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp5_ < 10) {
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		result = TRUE;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (best_scores);
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return result;
#line 1432 "context.c"
	}
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = best_scores;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = gee_list_get (_tmp6_, 9);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = (GamesScoresScore*) _tmp7_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp9_ = games_scores_score_get_score (_tmp8_);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10_ = _tmp9_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp11_ = _tmp10_;
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_tmp8_);
#line 190 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	lowest = _tmp11_;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp13_ = self->priv->style;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp13_ == GAMES_SCORES_STYLE_POINTS_LESS_IS_BETTER) {
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp12_ = TRUE;
#line 1456 "context.c"
	} else {
		GamesScoresStyle _tmp14_ = 0;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp14_ = self->priv->style;
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp12_ = _tmp14_ == GAMES_SCORES_STYLE_TIME_LESS_IS_BETTER;
#line 1463 "context.c"
	}
#line 192 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp12_) {
#line 1467 "context.c"
		glong _tmp15_ = 0L;
		glong _tmp16_ = 0L;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp15_ = score_value;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp16_ = lowest;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		result = _tmp15_ < _tmp16_;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (best_scores);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return result;
#line 1480 "context.c"
	}
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp17_ = score_value;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp18_ = lowest;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _tmp17_ > _tmp18_;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (best_scores);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 1492 "context.c"
}


static void games_scores_context_save_score_to_file_data_free (gpointer _data) {
	GamesScoresContextSaveScoreToFileData* _data_;
	_data_ = _data;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->score);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->category);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->cancellable);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_slice_free (GamesScoresContextSaveScoreToFileData, _data_);
#line 1509 "context.c"
}


static void games_scores_context_save_score_to_file (GamesScoresContext* self, GamesScoresScore* score, GamesScoresCategory* category, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GamesScoresContextSaveScoreToFileData* _data_;
	GamesScoresContext* _tmp0_ = NULL;
	GamesScoresScore* _tmp1_ = NULL;
	GamesScoresScore* _tmp2_ = NULL;
	GamesScoresCategory* _tmp3_ = NULL;
	GamesScoresCategory* _tmp4_ = NULL;
	GCancellable* _tmp5_ = NULL;
	GCancellable* _tmp6_ = NULL;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = g_slice_new0 (GamesScoresContextSaveScoreToFileData);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, games_scores_context_save_score_to_file);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, games_scores_context_save_score_to_file_data_free);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->self = _tmp0_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = score;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->score);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->score = _tmp2_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = category;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->category);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->category = _tmp4_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = cancellable;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->cancellable);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->cancellable = _tmp6_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_save_score_to_file_co (_data_);
#line 1558 "context.c"
}


static void games_scores_context_save_score_to_file_finish (GamesScoresContext* self, GAsyncResult* _res_, GError** error) {
	GamesScoresContextSaveScoreToFileData* _data_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return;
#line 1568 "context.c"
	}
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1572 "context.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1431 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1432 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	result = self;
#line 1432 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 1584 "context.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1417 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1418 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1418 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1418 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1419 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1419 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1419 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1419 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 1628 "context.c"
	}
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1420 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 1634 "context.c"
}


static void games_scores_context_save_score_to_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	GamesScoresContextSaveScoreToFileData* _data_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = _user_data_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_source_object_ = source_object;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_res_ = _res_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_save_score_to_file_co (_data_);
#line 1648 "context.c"
}


static gboolean games_scores_context_save_score_to_file_co (GamesScoresContextSaveScoreToFileData* _data_) {
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	switch (_data_->_state_) {
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		case 0:
#line 1657 "context.c"
		goto _state_0;
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		case 1:
#line 1661 "context.c"
		goto _state_1;
		default:
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_assert_not_reached ();
#line 1666 "context.c"
	}
	_state_0:
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp0_ = NULL;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp0_ = _data_->self->priv->user_score_dir;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp1_ = 0;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp1_ = g_mkdir_with_parents (_data_->_tmp0_, 0766);
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_tmp1_ == -1) {
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp2_ = NULL;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp2_ = _data_->self->priv->user_score_dir;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp3_ = 0;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp3_ = errno;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp4_ = NULL;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp4_ = g_strerror (_data_->_tmp3_);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp5_ = NULL;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp5_ = g_error_new (G_FILE_ERROR, G_FILE_ERROR_FAILED, "Failed to create %s: %s", _data_->_tmp2_, _data_->_tmp4_);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_inner_error_ = _data_->_tmp5_;
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_error_free (_data_->_inner_error_);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_data_->_state_ == 0) {
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1705 "context.c"
		} else {
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1709 "context.c"
		}
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_object_unref (_data_->_async_result);
#line 202 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 1715 "context.c"
	}
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp6_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp6_ = _data_->self->priv->user_score_dir;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp7_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp7_ = _data_->category;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp8_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp8_ = games_scores_category_get_key (_data_->_tmp7_);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp9_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp10_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp10_ = g_build_filename (_data_->_tmp6_, _data_->_tmp9_, NULL);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp11_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp12_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp12_ = g_file_new_for_path (_data_->_tmp11_);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp13_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (_data_->_tmp11_);
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->file = _data_->_tmp13_;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp14_ = NULL;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp14_ = _data_->file;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp15_ = NULL;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp15_ = g_file_append_to (_data_->_tmp14_, G_FILE_CREATE_NONE, NULL, &_data_->_inner_error_);
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->stream = _data_->_tmp15_;
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_error_free (_data_->_inner_error_);
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_data_->file);
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_data_->_state_ == 0) {
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1775 "context.c"
		} else {
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1779 "context.c"
		}
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_object_unref (_data_->_async_result);
#line 206 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 1785 "context.c"
	}
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp16_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp16_ = _data_->score;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp17_ = 0L;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp17_ = games_scores_score_get_score (_data_->_tmp16_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp18_ = 0L;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp19_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp19_ = g_strdup_printf ("%li", _data_->_tmp18_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp20_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp21_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp21_ = _data_->score;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp22_ = 0LL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp22_ = games_scores_score_get_time (_data_->_tmp21_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp23_ = 0LL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp23_ = _data_->_tmp22_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp24_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp24_ = g_strdup_printf ("%" G_GINT64_FORMAT, _data_->_tmp23_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp25_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp26_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp26_ = _data_->score;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp27_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp27_ = games_scores_score_get_user (_data_->_tmp26_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp28_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp28_ = _data_->_tmp27_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp29_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp29_ = string_to_string (_data_->_tmp28_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp30_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp30_ = g_strconcat (_data_->_tmp20_, " ", _data_->_tmp25_, " ", _data_->_tmp29_, "\n", NULL);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp31_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (_data_->_tmp25_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (_data_->_tmp20_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->line = _data_->_tmp31_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp32_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp32_ = _data_->stream;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp33_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp33_ = _data_->line;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp34_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp34__length1 = 0;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp34_ = string_get_data (_data_->_tmp33_, &_data_->_tmp34__length1);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp35_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp35__length1 = 0;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp35__length1 = _data_->_tmp34__length1;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp36_ = NULL;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp36_ = _data_->cancellable;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_state_ = 1;
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_output_stream_write_all_async ((GOutputStream*) _data_->_tmp32_, _data_->_tmp35_, (gsize) _data_->_tmp35__length1, G_PRIORITY_DEFAULT, _data_->_tmp36_, games_scores_context_save_score_to_file_ready, _data_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 1889 "context.c"
	_state_1:
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_output_stream_write_all_finish ((GOutputStream*) _data_->_tmp32_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_error_free (_data_->_inner_error_);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_free0 (_data_->line);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_data_->stream);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_data_->file);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_data_->_state_ == 0) {
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1909 "context.c"
		} else {
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1913 "context.c"
		}
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_object_unref (_data_->_async_result);
#line 209 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 1919 "context.c"
	}
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (_data_->line);
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->stream);
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->file);
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_state_ == 0) {
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1931 "context.c"
	} else {
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1935 "context.c"
	}
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_object_unref (_data_->_async_result);
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 1941 "context.c"
}


static void games_scores_context_add_score_internal_data_free (gpointer _data) {
	GamesScoresContextAddScoreInternalData* _data_;
	_data_ = _data;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->score);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->category);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->cancellable);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_slice_free (GamesScoresContextAddScoreInternalData, _data_);
#line 1958 "context.c"
}


void games_scores_context_add_score_internal (GamesScoresContext* self, GamesScoresScore* score, GamesScoresCategory* category, gboolean allow_dialog, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GamesScoresContextAddScoreInternalData* _data_;
	GamesScoresContext* _tmp0_ = NULL;
	GamesScoresScore* _tmp1_ = NULL;
	GamesScoresScore* _tmp2_ = NULL;
	GamesScoresCategory* _tmp3_ = NULL;
	GamesScoresCategory* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GCancellable* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = g_slice_new0 (GamesScoresContextAddScoreInternalData);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, games_scores_context_add_score_internal);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, games_scores_context_add_score_internal_data_free);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->self = _tmp0_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = score;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->score);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->score = _tmp2_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = category;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->category);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->category = _tmp4_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = allow_dialog;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->allow_dialog = _tmp5_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = cancellable;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->cancellable);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->cancellable = _tmp7_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_add_score_internal_co (_data_);
#line 2012 "context.c"
}


gboolean games_scores_context_add_score_internal_finish (GamesScoresContext* self, GAsyncResult* _res_, GError** error) {
	gboolean result;
	GamesScoresContextAddScoreInternalData* _data_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 2023 "context.c"
	}
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _data_->result;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 2031 "context.c"
}


static void games_scores_context_add_score_internal_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	GamesScoresContextAddScoreInternalData* _data_;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = _user_data_;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_source_object_ = source_object;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_res_ = _res_;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_add_score_internal_co (_data_);
#line 2045 "context.c"
}


static gboolean games_scores_context_add_score_internal_co (GamesScoresContextAddScoreInternalData* _data_) {
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	switch (_data_->_state_) {
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		case 0:
#line 2054 "context.c"
		goto _state_0;
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		case 1:
#line 2058 "context.c"
		goto _state_1;
		default:
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_assert_not_reached ();
#line 2063 "context.c"
	}
	_state_0:
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp0_ = NULL;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp0_ = _data_->score;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp1_ = 0L;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp1_ = games_scores_score_get_score (_data_->_tmp0_);
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp2_ = 0L;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp3_ = NULL;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp3_ = _data_->category;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp4_ = FALSE;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp4_ = games_scores_context_is_high_score (_data_->self, _data_->_tmp2_, _data_->_tmp3_);
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->high_score_added = _data_->_tmp4_;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp5_ = NULL;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp5_ = _data_->self->priv->scores_per_category;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp6_ = NULL;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp6_ = _data_->category;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp7_ = FALSE;
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp7_ = gee_abstract_map_has_key ((GeeAbstractMap*) _data_->_tmp5_, _data_->_tmp6_);
#line 220 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (!_data_->_tmp7_) {
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp8_ = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp8_ = _data_->self->priv->scores_per_category;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp9_ = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp9_ = _data_->category;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp10_ = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp10__target = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp10__target_destroy_notify = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp10_ = _data_->self->priv->scorecmp;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp10__target = _data_->self->priv->scorecmp_target;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp10__target_destroy_notify = _data_->self->priv->scorecmp_target_destroy_notify;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->self->priv->scorecmp_target_destroy_notify = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp11_ = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp11_ = gee_priority_queue_new (GAMES_SCORES_TYPE_SCORE, (GBoxedCopyFunc) g_object_ref, g_object_unref, _data_->_tmp10_, _data_->_tmp10__target, _data_->_tmp10__target_destroy_notify);
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp12_ = NULL;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp8_, _data_->_tmp9_, _data_->_tmp12_);
#line 221 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_data_->_tmp12_);
#line 2136 "context.c"
	}
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp13_ = NULL;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp13_ = _data_->self->priv->scores_per_category;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp14_ = NULL;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp14_ = _data_->category;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp15_ = NULL;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp15_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp13_, _data_->_tmp14_);
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp16_ = NULL;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp16_ = (GeePriorityQueue*) _data_->_tmp15_;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp17_ = NULL;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp17_ = _data_->score;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp18_ = FALSE;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp18_ = gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp16_, _data_->_tmp17_);
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp19_ = FALSE;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->_tmp16_);
#line 223 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_tmp19_) {
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp20_ = NULL;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp20_ = _data_->category;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp21_ = NULL;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp21_ = _g_object_ref0 (_data_->_tmp20_);
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_data_->self->priv->current_category);
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->self->priv->current_category = _data_->_tmp21_;
#line 2182 "context.c"
	}
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp23_ = FALSE;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp23_ = _data_->high_score_added;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_tmp23_) {
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp24_ = FALSE;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp24_ = _data_->allow_dialog;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp22_ = _data_->_tmp24_;
#line 2196 "context.c"
	} else {
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp22_ = FALSE;
#line 2200 "context.c"
	}
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_tmp22_) {
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp25_ = NULL;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data_->_tmp25_ = _data_->score;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		games_scores_context_run_dialog_internal (_data_->self, _data_->_tmp25_);
#line 2210 "context.c"
	}
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp26_ = NULL;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp26_ = _data_->score;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp27_ = NULL;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp27_ = _data_->self->priv->current_category;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp28_ = NULL;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp28_ = _data_->cancellable;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_state_ = 1;
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_save_score_to_file (_data_->self, _data_->_tmp26_, _data_->_tmp27_, _data_->_tmp28_, games_scores_context_add_score_internal_ready, _data_);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 2230 "context.c"
	_state_1:
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_save_score_to_file_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_error_free (_data_->_inner_error_);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_data_->_state_ == 0) {
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2244 "context.c"
		} else {
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2248 "context.c"
		}
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_object_unref (_data_->_async_result);
#line 232 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 2254 "context.c"
	}
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->result = _data_->high_score_added;
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_state_ == 0) {
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2262 "context.c"
	} else {
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2266 "context.c"
	}
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_object_unref (_data_->_async_result);
#line 233 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_state_ == 0) {
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2276 "context.c"
	} else {
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2280 "context.c"
	}
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_object_unref (_data_->_async_result);
#line 212 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 2286 "context.c"
}


static void games_scores_context_add_score_data_free (gpointer _data) {
	GamesScoresContextAddScoreData* _data_;
	_data_ = _data;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->category);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->cancellable);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->self);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_slice_free (GamesScoresContextAddScoreData, _data_);
#line 2301 "context.c"
}


void games_scores_context_add_score (GamesScoresContext* self, glong score, GamesScoresCategory* category, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GamesScoresContextAddScoreData* _data_;
	GamesScoresContext* _tmp0_ = NULL;
	glong _tmp1_ = 0L;
	GamesScoresCategory* _tmp2_ = NULL;
	GamesScoresCategory* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
	GCancellable* _tmp5_ = NULL;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = g_slice_new0 (GamesScoresContextAddScoreData);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, games_scores_context_add_score);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, games_scores_context_add_score_data_free);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->self = _tmp0_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = score;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->score = _tmp1_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = category;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->category);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->category = _tmp3_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = cancellable;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->cancellable);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->cancellable = _tmp5_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_add_score_co (_data_);
#line 2345 "context.c"
}


gboolean games_scores_context_add_score_finish (GamesScoresContext* self, GAsyncResult* _res_, GError** error) {
	gboolean result;
	GamesScoresContextAddScoreData* _data_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 2356 "context.c"
	}
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _data_->result;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 2364 "context.c"
}


static void games_scores_context_add_score_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	GamesScoresContextAddScoreData* _data_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_ = _user_data_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_source_object_ = source_object;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_res_ = _res_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_add_score_co (_data_);
#line 2378 "context.c"
}


static gboolean games_scores_context_add_score_co (GamesScoresContextAddScoreData* _data_) {
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	switch (_data_->_state_) {
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		case 0:
#line 2387 "context.c"
		goto _state_0;
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		case 1:
#line 2391 "context.c"
		goto _state_1;
		default:
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_assert_not_reached ();
#line 2396 "context.c"
	}
	_state_0:
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp1_ = 0L;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp1_ = _data_->score;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp2_ = NULL;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp2_ = games_scores_score_new (_data_->_tmp1_, (gint64) 0, NULL);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp3_ = NULL;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp4_ = NULL;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp4_ = _data_->category;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp5_ = NULL;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp5_ = _data_->self->priv->game_window;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp6_ = NULL;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp6_ = _data_->cancellable;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_state_ = 1;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_add_score_internal (_data_->self, _data_->_tmp3_, _data_->_tmp4_, _data_->_tmp5_ != NULL, _data_->_tmp6_, games_scores_context_add_score_ready, _data_);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 2429 "context.c"
	_state_1:
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp7_ = FALSE;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp7_ = games_scores_context_add_score_internal_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp8_ = FALSE;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (_data_->_tmp3_);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->_tmp0_ = _data_->_tmp8_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_error_free (_data_->_inner_error_);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_data_->_state_ == 0) {
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2453 "context.c"
		} else {
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2457 "context.c"
		}
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_object_unref (_data_->_async_result);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 2463 "context.c"
	}
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data_->result = _data_->_tmp0_;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_state_ == 0) {
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2471 "context.c"
	} else {
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2475 "context.c"
	}
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_object_unref (_data_->_async_result);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_data_->_state_ == 0) {
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2485 "context.c"
	} else {
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2489 "context.c"
	}
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_object_unref (_data_->_async_result);
#line 237 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return FALSE;
#line 2495 "context.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return _data3_;
#line 2504 "context.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 2513 "context.c"
		GamesScoresContext* self;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		self = _data3_->self;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_error_free0 (_data3_->_error_);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_main_loop_unref0 (_data3_->main_loop);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (self);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_slice_free (Block3Data, _data3_);
#line 2525 "context.c"
	}
}


static gpointer _g_error_copy0 (gpointer self) {
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return self ? g_error_copy (self) : NULL;
#line 2533 "context.c"
}


static void __lambda12_ (Block3Data* _data3_, GObject* object, GAsyncResult* _result_) {
	GamesScoresContext* self;
	GMainLoop* _tmp5_ = NULL;
	GError * _inner_error_ = NULL;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self = _data3_->self;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (_result_ != NULL);
#line 2545 "context.c"
	{
		gboolean _tmp0_ = FALSE;
		GAsyncResult* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp1_ = _result_;
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp2_ = games_scores_context_add_score_internal_finish (self, _tmp1_, &_inner_error_);
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp0_ = _tmp2_;
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2558 "context.c"
			goto __catch1_g_error;
		}
#line 254 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data3_->ret = _tmp0_;
#line 2563 "context.c"
	}
	goto __finally1;
	__catch1_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		GError* _tmp4_ = NULL;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		e = _inner_error_;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_inner_error_ = NULL;
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp3_ = e;
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp4_ = _g_error_copy0 (_tmp3_);
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_error_free0 (_data3_->_error_);
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data3_->_error_ = _tmp4_;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_error_free0 (e);
#line 2585 "context.c"
	}
	__finally1:
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_clear_error (&_inner_error_);
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return;
#line 2596 "context.c"
	}
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = _data3_->main_loop;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_main_loop_quit (_tmp5_);
#line 2602 "context.c"
}


static void ___lambda12__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	__lambda12_ (self, source_object, res);
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	block3_data_unref (self);
#line 2611 "context.c"
}


gboolean games_scores_context_add_score_sync (GamesScoresContext* self, GamesScoresScore* score, GamesScoresCategory* category, GError** error) {
	gboolean result = FALSE;
	Block3Data* _data3_;
	GMainContext* main_context = NULL;
	GMainContext* _tmp0_ = NULL;
	GMainContext* _tmp1_ = NULL;
	GMainLoop* _tmp2_ = NULL;
	GMainContext* _tmp3_ = NULL;
	GamesScoresScore* _tmp4_ = NULL;
	GamesScoresCategory* _tmp5_ = NULL;
	GMainLoop* _tmp6_ = NULL;
	GMainContext* _tmp7_ = NULL;
	GError* _tmp8_ = NULL;
	gboolean _tmp11_ = FALSE;
	GError * _inner_error_ = NULL;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (score != NULL, FALSE);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (category != NULL, FALSE);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_->_ref_count_ = 1;
#line 243 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_->self = g_object_ref (self);
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = g_main_context_new ();
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	main_context = _tmp0_;
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = main_context;
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = g_main_loop_new (_tmp1_, FALSE);
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_->main_loop = _tmp2_;
#line 247 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_->ret = FALSE;
#line 248 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_->_error_ = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = main_context;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_main_context_push_thread_default (_tmp3_);
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = score;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = category;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_add_score_internal (self, _tmp4_, _tmp5_, FALSE, NULL, ___lambda12__gasync_ready_callback, block3_data_ref (_data3_));
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = _data3_->main_loop;
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_main_loop_run (_tmp6_);
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = main_context;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_main_context_pop_thread_default (_tmp7_);
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = _data3_->_error_;
#line 265 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp8_ != NULL) {
#line 2678 "context.c"
		GError* _tmp9_ = NULL;
		GError* _tmp10_ = NULL;
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp9_ = _data3_->_error_;
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp10_ = _g_error_copy0 (_tmp9_);
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_inner_error_ = _tmp10_;
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_propagate_error (error, _inner_error_);
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_main_context_unref0 (main_context);
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		block3_data_unref (_data3_);
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_data3_ = NULL;
#line 266 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return FALSE;
#line 2697 "context.c"
	}
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp11_ = _data3_->ret;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = _tmp11_;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_main_context_unref0 (main_context);
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	block3_data_unref (_data3_);
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_data3_ = NULL;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 2711 "context.c"
}


static gchar* g_file_stream_read_line (FILE* self) {
	gchar* result = NULL;
	gint c = 0;
	GString* ret = NULL;
	GString* _tmp7_ = NULL;
#line 3511 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 3513 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	ret = NULL;
#line 3514 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	while (TRUE) {
#line 2726 "context.c"
		gint _tmp0_ = 0;
		gint _tmp1_ = 0;
		GString* _tmp2_ = NULL;
		gint _tmp4_ = 0;
		GString* _tmp5_ = NULL;
		gint _tmp6_ = 0;
#line 3514 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = fgetc (self);
#line 3514 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		c = _tmp0_;
#line 3514 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = c;
#line 3514 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		if (!(_tmp1_ != EOF)) {
#line 3514 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
			break;
#line 2743 "context.c"
		}
#line 3515 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = ret;
#line 3515 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp2_ == NULL) {
#line 2749 "context.c"
			GString* _tmp3_ = NULL;
#line 3516 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp3_ = g_string_new ("");
#line 3516 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_string_free0 (ret);
#line 3516 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
			ret = _tmp3_;
#line 2757 "context.c"
		}
#line 3518 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = c;
#line 3518 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp4_ == ((gint) '\n')) {
#line 3519 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
			break;
#line 2765 "context.c"
		}
#line 3521 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = ret;
#line 3521 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = c;
#line 3521 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		g_string_append_c ((GString*) _tmp5_, (gchar) _tmp6_);
#line 2773 "context.c"
	}
#line 3523 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp7_ = ret;
#line 3523 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp7_ == NULL) {
#line 3524 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		result = NULL;
#line 3524 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_string_free0 (ret);
#line 3524 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 2785 "context.c"
	} else {
		GString* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 3526 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp8_ = ret;
#line 3526 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = ((GString*) _tmp8_)->str;
#line 3526 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = g_strdup (_tmp9_);
#line 3526 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp10_;
#line 3526 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_string_free0 (ret);
#line 3526 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 2802 "context.c"
	}
#line 3511 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_g_string_free0 (ret);
#line 2806 "context.c"
}


static gint64 int64_parse (const gchar* str) {
	gint64 result = 0LL;
	const gchar* _tmp0_ = NULL;
	gint64 _tmp1_ = 0LL;
#line 679 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, 0LL);
#line 680 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 680 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = g_ascii_strtoll (_tmp0_, NULL, (guint) 0);
#line 680 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 680 "/home/mcatanzaro/src/jhbuild/install/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 2824 "context.c"
}


static void games_scores_context_load_scores_from_file (GamesScoresContext* self, GFileInfo* file_info, GError** error) {
	gchar* category_key = NULL;
	GFileInfo* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GamesScoresCategory* category = NULL;
	GamesScoresContextCategoryRequestFunc _tmp3_ = NULL;
	void* _tmp3__target = NULL;
	const gchar* _tmp4_ = NULL;
	GamesScoresCategory* _tmp5_ = NULL;
	GamesScoresCategory* _tmp6_ = NULL;
	gchar* filename = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	GeePriorityQueue* scores_of_single_category = NULL;
	GCompareDataFunc _tmp10_ = NULL;
	void* _tmp10__target = NULL;
	GDestroyNotify _tmp10__target_destroy_notify = NULL;
	GeePriorityQueue* _tmp11_ = NULL;
	FILE* stream = NULL;
	const gchar* _tmp12_ = NULL;
	FILE* _tmp13_ = NULL;
	gchar* line = NULL;
	GeeHashMap* _tmp52_ = NULL;
	GamesScoresCategory* _tmp53_ = NULL;
	GeePriorityQueue* _tmp54_ = NULL;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (self != NULL);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (file_info != NULL);
#line 272 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = file_info;
#line 272 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = g_file_info_get_name (_tmp0_);
#line 272 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 272 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	category_key = _tmp2_;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = self->priv->category_request;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3__target = self->priv->category_request_target;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = category_key;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = _tmp3_ (_tmp4_, _tmp3__target);
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	category = _tmp5_;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = category;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp6_ == NULL) {
#line 275 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (category);
#line 275 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_free0 (category_key);
#line 275 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return;
#line 2887 "context.c"
	}
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = self->priv->user_score_dir;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = category_key;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp9_ = g_build_filename (_tmp7_, _tmp8_, NULL);
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	filename = _tmp9_;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10_ = self->priv->scorecmp;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10__target = self->priv->scorecmp_target;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10__target_destroy_notify = self->priv->scorecmp_target_destroy_notify;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->scorecmp_target_destroy_notify = NULL;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp11_ = gee_priority_queue_new (GAMES_SCORES_TYPE_SCORE, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp10_, _tmp10__target, _tmp10__target_destroy_notify);
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	scores_of_single_category = _tmp11_;
#line 279 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp12_ = filename;
#line 279 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp13_ = g_fopen (_tmp12_, "r");
#line 279 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	stream = _tmp13_;
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	while (TRUE) {
#line 2917 "context.c"
		FILE* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		gchar** tokens = NULL;
		const gchar* _tmp17_ = NULL;
		gchar** _tmp18_ = NULL;
		gchar** _tmp19_ = NULL;
		gint tokens_length1 = 0;
		gint _tokens_size_ = 0;
		gchar* user = NULL;
		gchar** _tmp20_ = NULL;
		gint _tmp20__length1 = 0;
		glong score_value = 0L;
		gchar** _tmp23_ = NULL;
		gint _tmp23__length1 = 0;
		const gchar* _tmp24_ = NULL;
		glong _tmp25_ = 0L;
		gint64 time = 0LL;
		gchar** _tmp26_ = NULL;
		gint _tmp26__length1 = 0;
		const gchar* _tmp27_ = NULL;
		gint64 _tmp28_ = 0LL;
		gboolean _tmp29_ = FALSE;
		gboolean _tmp30_ = FALSE;
		glong _tmp31_ = 0L;
		gchar** _tmp40_ = NULL;
		gint _tmp40__length1 = 0;
		GeePriorityQueue* _tmp46_ = NULL;
		glong _tmp47_ = 0L;
		gint64 _tmp48_ = 0LL;
		const gchar* _tmp49_ = NULL;
		GamesScoresScore* _tmp50_ = NULL;
		GamesScoresScore* _tmp51_ = NULL;
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp14_ = stream;
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp15_ = g_file_stream_read_line (_tmp14_);
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_free0 (line);
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		line = _tmp15_;
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp16_ = line;
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (!(_tmp16_ != NULL)) {
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			break;
#line 2965 "context.c"
		}
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp17_ = line;
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp19_ = _tmp18_ = g_strsplit (_tmp17_, " ", 3);
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		tokens = _tmp19_;
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		tokens_length1 = _vala_array_length (_tmp18_);
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tokens_size_ = tokens_length1;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		user = NULL;
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp20_ = tokens;
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp20__length1 = tokens_length1;
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_tmp20__length1 < 2) {
#line 2985 "context.c"
			const gchar* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp21_ = line;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp22_ = filename;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_warning ("context.vala:288: Failed to read malformed score %s in %s.", _tmp21_, _tmp22_);
#line 289 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_free0 (user);
#line 289 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 289 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			continue;
#line 3000 "context.c"
		}
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp23_ = tokens;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp23__length1 = tokens_length1;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp24_ = _tmp23_[0];
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp25_ = atol (_tmp24_);
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		score_value = _tmp25_;
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp26_ = tokens;
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp26__length1 = tokens_length1;
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp27_ = _tmp26_[1];
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp28_ = int64_parse (_tmp27_);
#line 293 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		time = _tmp28_;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp31_ = score_value;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_tmp31_ == ((glong) 0)) {
#line 3026 "context.c"
			gchar** _tmp32_ = NULL;
			gint _tmp32__length1 = 0;
			const gchar* _tmp33_ = NULL;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp32_ = tokens;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp32__length1 = tokens_length1;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp33_ = _tmp32_[0];
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp30_ = g_strcmp0 (_tmp33_, "0") != 0;
#line 3038 "context.c"
		} else {
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp30_ = FALSE;
#line 3042 "context.c"
		}
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_tmp30_) {
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp29_ = TRUE;
#line 3048 "context.c"
		} else {
			gboolean _tmp34_ = FALSE;
			gint64 _tmp35_ = 0LL;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp35_ = time;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			if (_tmp35_ == ((gint64) 0)) {
#line 3056 "context.c"
				gchar** _tmp36_ = NULL;
				gint _tmp36__length1 = 0;
				const gchar* _tmp37_ = NULL;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp36_ = tokens;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp36__length1 = tokens_length1;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp37_ = _tmp36_[1];
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp34_ = g_strcmp0 (_tmp37_, "0") != 0;
#line 3068 "context.c"
			} else {
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_tmp34_ = FALSE;
#line 3072 "context.c"
			}
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp29_ = _tmp34_;
#line 3076 "context.c"
		}
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_tmp29_) {
#line 3080 "context.c"
			const gchar* _tmp38_ = NULL;
			const gchar* _tmp39_ = NULL;
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp38_ = line;
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp39_ = filename;
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_warning ("context.vala:298: Failed to read malformed score %s in %s.", _tmp38_, _tmp39_);
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_free0 (user);
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 299 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			continue;
#line 3095 "context.c"
		}
#line 302 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp40_ = tokens;
#line 302 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp40__length1 = tokens_length1;
#line 302 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (_tmp40__length1 == 3) {
#line 3103 "context.c"
			gchar** _tmp41_ = NULL;
			gint _tmp41__length1 = 0;
			const gchar* _tmp42_ = NULL;
			gchar* _tmp43_ = NULL;
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp41_ = tokens;
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp41__length1 = tokens_length1;
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp42_ = _tmp41_[2];
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp43_ = g_strdup (_tmp42_);
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_free0 (user);
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			user = _tmp43_;
#line 3120 "context.c"
		} else {
			const gchar* _tmp44_ = NULL;
			const gchar* _tmp45_ = NULL;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp44_ = line;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp45_ = filename;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_debug ("context.vala:305: Assuming current username for old score %s in %s.", _tmp44_, _tmp45_);
#line 3130 "context.c"
		}
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp46_ = scores_of_single_category;
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp47_ = score_value;
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp48_ = time;
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp49_ = user;
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp50_ = games_scores_score_new (_tmp47_, _tmp48_, _tmp49_);
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp51_ = _tmp50_;
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp46_, _tmp51_);
#line 307 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_tmp51_);
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_free0 (user);
#line 281 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		tokens = (_vala_array_free (tokens, tokens_length1, (GDestroyNotify) g_free), NULL);
#line 3152 "context.c"
	}
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp52_ = self->priv->scores_per_category;
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp53_ = category;
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp54_ = scores_of_single_category;
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	gee_abstract_map_set ((GeeAbstractMap*) _tmp52_, _tmp53_, _tmp54_);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (line);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_fclose0 (stream);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (scores_of_single_category);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (filename);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (category);
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (category_key);
#line 3174 "context.c"
}


static void games_scores_context_load_scores_from_files (GamesScoresContext* self, GError** error) {
	gboolean _tmp0_ = FALSE;
	GtkWindow* _tmp1_ = NULL;
	GFile* directory = NULL;
	const gchar* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
	GFile* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	GFileEnumerator* enumerator = NULL;
	GFile* _tmp9_ = NULL;
	GFileEnumerator* _tmp10_ = NULL;
	GFileInfo* file_info = NULL;
	GError * _inner_error_ = NULL;
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (self != NULL);
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = self->priv->game_window;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp1_ != NULL) {
#line 3197 "context.c"
		GtkWindow* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp2_ = self->priv->game_window;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp3_ = gtk_widget_get_visible ((GtkWidget*) _tmp2_);
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp4_ = _tmp3_;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp0_ = _tmp4_;
#line 3209 "context.c"
	} else {
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp0_ = FALSE;
#line 3213 "context.c"
	}
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (_tmp0_) {
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_error ("context.vala:317: %s", "The application window associated with the GamesScoresContext " "was set visible before the Context was constructed. The Context " "performs synchronous I/O in the default main context to load " "scores when it is constructed, so you should create the Context " "before showing your main window.");
#line 3219 "context.c"
	}
#line 324 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = self->priv->user_score_dir;
#line 324 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = g_file_new_for_path (_tmp5_);
#line 324 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	directory = _tmp6_;
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = directory;
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp8_ = g_file_query_exists (_tmp7_, NULL);
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (!_tmp8_) {
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (directory);
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return;
#line 3237 "context.c"
	}
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp9_ = directory;
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp10_ = g_file_enumerate_children (_tmp9_, G_FILE_ATTRIBUTE_STANDARD_NAME, 0, NULL, &_inner_error_);
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	enumerator = _tmp10_;
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		g_propagate_error (error, _inner_error_);
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (directory);
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		return;
#line 3253 "context.c"
	}
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	while (TRUE) {
#line 3257 "context.c"
		GFileInfo* _tmp11_ = NULL;
		GFileEnumerator* _tmp12_ = NULL;
		GFileInfo* _tmp13_ = NULL;
		GFileInfo* _tmp14_ = NULL;
		GFileInfo* _tmp15_ = NULL;
		GFileInfo* _tmp16_ = NULL;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp12_ = enumerator;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp13_ = g_file_enumerator_next_file (_tmp12_, NULL, &_inner_error_);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp11_ = _tmp13_;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_propagate_error (error, _inner_error_);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (file_info);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (enumerator);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (directory);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			return;
#line 3282 "context.c"
		}
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp14_ = _tmp11_;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp11_ = NULL;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (file_info);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		file_info = _tmp14_;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp15_ = file_info;
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (!(_tmp15_ != NULL)) {
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (_tmp11_);
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			break;
#line 3300 "context.c"
		}
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp16_ = file_info;
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		games_scores_context_load_scores_from_file (self, _tmp16_, &_inner_error_);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			g_propagate_error (error, _inner_error_);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (_tmp11_);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (file_info);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (enumerator);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (directory);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			return;
#line 3320 "context.c"
		}
#line 330 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_tmp11_);
#line 3324 "context.c"
	}
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (file_info);
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (enumerator);
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (directory);
#line 3332 "context.c"
}


void games_scores_context_run_dialog_internal (GamesScoresContext* self, GamesScoresScore* new_high_score) {
	GtkWindow* _tmp0_ = NULL;
	GamesScoresDialog* dialog = NULL;
	const gchar* _tmp1_ = NULL;
	GamesScoresStyle _tmp2_ = 0;
	GamesScoresScore* _tmp3_ = NULL;
	GamesScoresCategory* _tmp4_ = NULL;
	GtkWindow* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GamesScoresDialog* _tmp7_ = NULL;
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (self != NULL);
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = self->priv->game_window;
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_vala_return_if_fail (_tmp0_ != NULL, "game_window != null");
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = self->priv->category_type;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = self->priv->style;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp3_ = new_high_score;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp4_ = self->priv->current_category;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp5_ = self->priv->game_window;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp6_ = self->priv->app_name;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp7_ = games_scores_dialog_new (self, _tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_object_ref_sink (_tmp7_);
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	dialog = _tmp7_;
#line 340 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	gtk_dialog_run ((GtkDialog*) dialog);
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	gtk_widget_destroy ((GtkWidget*) dialog);
#line 336 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (dialog);
#line 3376 "context.c"
}


void games_scores_context_run_dialog (GamesScoresContext* self) {
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_if_fail (self != NULL);
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_run_dialog_internal (self, NULL);
#line 3385 "context.c"
}


gboolean games_scores_context_has_scores (GamesScoresContext* self) {
	gboolean result = FALSE;
#line 349 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 3393 "context.c"
	{
		GeeIterator* _scores_it = NULL;
		GeeHashMap* _tmp0_ = NULL;
		GeeCollection* _tmp1_ = NULL;
		GeeCollection* _tmp2_ = NULL;
		GeeCollection* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp0_ = self->priv->scores_per_category;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp1_ = gee_abstract_map_get_values ((GeeMap*) _tmp0_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp2_ = _tmp1_;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp3_ = _tmp2_;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_tmp5_ = _tmp4_;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_tmp3_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_scores_it = _tmp5_;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		while (TRUE) {
#line 3420 "context.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			GeePriorityQueue* scores = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			GeePriorityQueue* _tmp10_ = NULL;
			gint _tmp11_ = 0;
			gint _tmp12_ = 0;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp6_ = _scores_it;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			if (!_tmp7_) {
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				break;
#line 3437 "context.c"
			}
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp8_ = _scores_it;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			scores = (GeePriorityQueue*) _tmp9_;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp10_ = scores;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp11_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp10_);
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_tmp12_ = _tmp11_;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			if (_tmp12_ > 0) {
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				result = TRUE;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_g_object_unref0 (scores);
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				_g_object_unref0 (_scores_it);
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
				return result;
#line 3461 "context.c"
			}
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
			_g_object_unref0 (scores);
#line 3465 "context.c"
		}
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
		_g_object_unref0 (_scores_it);
#line 3469 "context.c"
	}
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	result = FALSE;
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	return result;
#line 3475 "context.c"
}


static void games_scores_context_base_init (GamesScoresContextClass * klass) {
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
#line 3484 "context.c"
}


static void games_scores_context_class_init (GamesScoresContextClass * klass) {
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_parent_class = g_type_class_peek_parent (klass);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	g_type_class_add_private (klass, sizeof (GamesScoresContextPrivate));
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	G_OBJECT_CLASS (klass)->finalize = games_scores_context_finalize;
#line 49 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_category_hash = __games_scores_context_category_hash_lambda4__gee_hash_data_func;
#line 53 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_category_equal = __games_scores_context_category_equal_lambda5__gee_equal_data_func;
#line 3499 "context.c"
}


static void games_scores_context_instance_init (GamesScoresContext * self) {
	GeeHashDataFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GDestroyNotify _tmp0__target_destroy_notify = NULL;
	GeeEqualDataFunc _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	GDestroyNotify _tmp1__target_destroy_notify = NULL;
	GeeHashMap* _tmp2_ = NULL;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv = GAMES_SCORES_CONTEXT_GET_PRIVATE (self);
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->current_category = NULL;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0_ = games_scores_context_category_hash;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0__target = games_scores_context_category_hash_target;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp0__target_destroy_notify = games_scores_context_category_hash_target_destroy_notify;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_category_hash_target_destroy_notify = NULL;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1_ = games_scores_context_category_equal;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1__target = games_scores_context_category_equal_target;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp1__target_destroy_notify = games_scores_context_category_equal_target_destroy_notify;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	games_scores_context_category_equal_target_destroy_notify = NULL;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_tmp2_ = gee_hash_map_new (GAMES_SCORES_TYPE_CATEGORY, (GBoxedCopyFunc) g_object_ref, g_object_unref, GEE_TYPE_PRIORITY_QUEUE, (GBoxedCopyFunc) g_object_ref, g_object_unref, _tmp0_, _tmp0__target, _tmp0__target_destroy_notify, _tmp1_, _tmp1__target, _tmp1__target_destroy_notify, NULL, NULL, NULL);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->scores_per_category = _tmp2_;
#line 3535 "context.c"
}


static void games_scores_context_finalize (GObject* obj) {
	GamesScoresContext * self;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GAMES_SCORES_TYPE_CONTEXT, GamesScoresContext);
#line 36 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (self->priv->current_category);
#line 38 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (self->priv->category_type);
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (self->priv->game_window);
#line 40 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (self->priv->app_name);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (self->priv->scores_per_category);
#line 45 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_free0 (self->priv->user_score_dir);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	(self->priv->scorecmp_target_destroy_notify == NULL) ? NULL : (self->priv->scorecmp_target_destroy_notify (self->priv->scorecmp_target), NULL);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->scorecmp = NULL;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->scorecmp_target = NULL;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->scorecmp_target_destroy_notify = NULL;
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	(self->priv->category_request_target_destroy_notify == NULL) ? NULL : (self->priv->category_request_target_destroy_notify (self->priv->category_request_target), NULL);
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request = NULL;
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request_target = NULL;
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	self->priv->category_request_target_destroy_notify = NULL;
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	_g_object_unref0 (self->priv->importer);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/libgnome-games-support/games/scores/context.vala"
	G_OBJECT_CLASS (games_scores_context_parent_class)->finalize (obj);
#line 3575 "context.c"
}


GType games_scores_context_get_type (void) {
	static volatile gsize games_scores_context_type_id__volatile = 0;
	if (g_once_init_enter (&games_scores_context_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GamesScoresContextClass), (GBaseInitFunc) games_scores_context_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) games_scores_context_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GamesScoresContext), 0, (GInstanceInitFunc) games_scores_context_instance_init, NULL };
		GType games_scores_context_type_id;
		games_scores_context_type_id = g_type_register_static (G_TYPE_OBJECT, "GamesScoresContext", &g_define_type_info, 0);
		g_once_init_leave (&games_scores_context_type_id__volatile, games_scores_context_type_id);
	}
	return games_scores_context_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



